@@ -1,3 +1,3 @@
 var a = /*#__PURE__*/ React.createElement("abbr", {
-    title: "d"
+    title: "\\d"
 }, "\\d");
